﻿using Syncfusion.DocIO.DLS;
using Syncfusion.DocToPDFConverter;
using Syncfusion.OfficeChartToImageConverter;
using Syncfusion.Pdf;
using System;
using System.IO;
using System.Net;
using System.Net.Http;
using System.Web.Http;

namespace DocIO_AspNetWebApi_ServiceApplication.Controllers
{
    public class WordToPDFController : ApiController
    {
        [AcceptVerbs("Post")]
        /// <summary>
        /// Converts the Word document to PDF document.
        /// </summary>
        public HttpResponseMessage ConvertToPDF()
        {
            HttpResponseMessage httpResponseMessage;
            using (Stream stream = Request.Content.ReadAsStreamAsync().Result)
            {
                try
                {
                    //Loads the Word document from stream
                    using (WordDocument wordDocument = new WordDocument(stream))
                    {
                        //Initializes the ChartToImageConverter for converting charts during Word to PDF conversion
                        wordDocument.ChartToImageConverter = new ChartToImageConverter();
                        wordDocument.ChartToImageConverter.ScalingMode = Syncfusion.OfficeChart.ScalingMode.Normal;
                        //Creates an instance of the DocToPDFConverter
                        DocToPDFConverter docToPdfConverter = new DocToPDFConverter();
                        //Converts Word document into PDF document
                        PdfDocument pdfDocument = docToPdfConverter.ConvertToPDF(wordDocument);
                        //Saves the PDF document to response stream
                        MemoryStream memoryStream = new MemoryStream();
                        pdfDocument.Save(memoryStream);
                        memoryStream.Position = 0;
                        httpResponseMessage = new HttpResponseMessage(HttpStatusCode.OK)
                        {
                            Content = new StreamContent(memoryStream)
                        };
                        pdfDocument.Dispose();
                    }
                }
                catch(Exception ex)
                {
                    httpResponseMessage = new HttpResponseMessage(HttpStatusCode.ExpectationFailed);
                }
            }
            return httpResponseMessage;
        }
    }
}
